#
# spec file for package praat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           praat
Version:        6.4.25
Release:        1.2
Summary:        Phonetics by computer
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Other
URL:            http://www.praat.org
Source0:        https://github.com/praat/praat/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.rpmlintrc
# PATCH-FIX-OPENSUSE praat-use_system_libs.patch -- replace some embedded libs with system ones
Patch1:         praat-use_system_libs.patch
# PATCH-FIX-OPENSUSE praat-no-return-in-nonvoid.patch -- make the compiler happy
Patch2:         praat-no-return-in-nonvoid.patch
# PATCH-FEATURE-OPENSUSE praat-allow-system-flags.patch badshah400@gmail.com -- Allow compilation and linker flags to incorporate appropriate env flags
Patch3:         praat-allow-system-flags.patch
BuildRequires:  gcc-c++
BuildRequires:  glpk-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  icns-utils
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lame)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)

%description
Praat is an open-software tool for the analysis of speech in phonetics.
Through its graphical interface, several speech analysis functionalities
are available: spectrograms, cochleograms, and pitch and formant extraction.
Articulatory synthesis, as well as synthesis from pitch, formant, and
intensity are also available. Other features are segmentation, labelling
using the phonetic alphabet, and computation of statistics.
Praat is configurable and extensible through its own scripting language and has
provisions for communicating with other programs.

%prep
%autosetup -p1

%build
cp makefiles/makefile.defs.linux.pulse ./makefile.defs
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%make_build

%install
mkdir -p %{buildroot}/%{_bindir} \
         %{buildroot}/%{_datadir}/pixmaps \
         %{buildroot}/%{_datadir}/applications
install -m 0755 %{name} %{buildroot}/%{_bindir}

icns2png -x -d32 main/Praat.icns
for s in 16 32 48 64 128 256 512; do
   if [ -f Praat_${s}x${s}x32.png ]; then
      mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
      install -m 0644 Praat_${s}x${s}x32.png %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
   fi
done

# create .desktop file
tee %{buildroot}/%{_datadir}/applications/%{name}.desktop << "EOF"
[Desktop Entry]
Version=1.0
Type=Application
Name=Praat
GenericName=Computer phonetics
Comment=Doing phonetics by computer
Exec=praat %U
TryExec=praat
Icon=praat
Terminal=false
Categories=Science;NumericalAnalysis;GTK;
StartupNotify=true
MimeType=text/praat-textgrid;text/praat-pitch;
EOF

%files
%license main/GNU_General_Public_License.txt
%doc README.md
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Wed Dec 18 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.25:
  * Command-line interface: solved a crash that occurred when a
    menu command was not available.
- Changes from version 6.4.24:
  * FormantPath: fixed bug with sampling frequency.
  * Formant measurements: fixed bugs in ”autocorrelation” and
    “robust” methods.
  * Manual: better support for screens taller than 15 inches.
  * Scripting: support for subtraction and unary minus for
    tensors.
  * Scripting: removed sendsocket.
- Changes from version 6.4.23:
  * Audio output: higher-quality playback of sounds with unusual
    sampling frequencies.
  * Scripting: better error messages on Save commands.
  * Better HTML output from manuals (e.g. italicized or bolded
    backslash sequences).
- Changes from version 6.4.22:
  * More robustness against trying to run a binary file as a
    script.
* Sun Sep 29 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.21:
  * SpeechSynthesizer: repaired an old bug whereby Get phonemes
    from text... could increase the duration of a subsequent Play
    (or To Sound...).
  * SpeechSynthesizer and TextGrid alignment: repaired a bug
    (existing since 6.4.18) whereby clause and word tiers would be
    empty.
  * TextGrid window: disambiguated Command-F5 (now Option-F5 for
    Get minimum pitch; likewise, Option-F8 for Get minimum
    intensity).
  * Calling Praat from command line: reenabled --pref-dir= option.
- Refresh praat-use_system_libs.patch for update.
* Tue Aug 13 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.17:
  * Spectrogram: Paint: solved a bug that could cause Praat to
    crash if the time domain was smaller than that of the
    Spectrogram.
  * ScriptEditor: Run selection can call procedures outside the
    selected text.
  * Audio files: can open Polyphone (Shorten) files.
* Fri Aug  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.16:
  * No Linux specific changes.
- Changes from version 6.4.15:
  * Distinguish between pitch ceiling (flat) and pitch top (curved
    ceiling), mainly because of their different meanings.
- Changes from version 6.4.14:
  * Pitch menu (in e.g. Sound or TextGrid window): separate
    settings for four pitch analysis methods.
  * Formant analysis: faster on all systems.
  * Pitch analysis: faster on Windows (Intel64 and Intel32).
  * TextGrids: Concatenate: guard against some incorrect TexGrid
    files.
* Mon Jul  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.13:
  * More manual pages.
  * Sounds: Concatenate with overlap...: guard against a crash
    that would occur if the total overlap time was longer than the
    original sounds together.
  * number recognizes hexadecimal numbers again.
* Thu Apr 25 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.10:
  * Function windows: fixed a problem that could cause Praat to
    crash when doing all after Group when windows had a different
    duration.
- Changes from version 6.4.09:
  * TextGrid window: fixed a rare problem with Align interval that
    could lead to a zero-length interval.
  * Sound & TextGrid: Align interval... now also available in the
    Objects window.
- Drop empty %%check section: rpmlint was misleading in
  recommending its addition.
* Sat Apr 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.08:
  * Scripting: fixed a bug that could cause Praat to crash when an
    unknown choice was given to an option menu.
  * MelSpectrogram: fixed a bug that could cause Praat to crash if
    a mel value was negative.
  * DataModeler: improved confidence limits on estimated model
    parameters.
- Add empty %%check section.
* Tue Mar 19 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.07:
  * The command Sound & Pitch: To PointProcess (cc), which is also
    used when computing the times of pulses in the Sound window,
    could cause Praat to freeze when the pitch ceiling (and the
    measured pitch) were very high; this problem existed since at
    least 2001.
  * eSpeak: new version, with e.g. Tigrinya.
  * Repaired a bug that could cause the Artword windows to crash
    if the Time field was left empty.
* Tue Mar 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.06:
  * FormantPathEditor without Sound: corrected several bugs that
    caused Praat to crash (such as Formant listing, using the
    Pitch menu...).
  * Spectrogram painting: improved painting of very quiet
    spectrograms at extreme dynamic ranges.
  * Scripting: folderExists.
  * Scripting: home-relative paths (such as ~/sounds/*.wav) in
    more locations, such as fileNames$#, Create Strings as file
    list..., and createFolder.
* Fri Feb  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.05:
  * Many typos in manual.
  * Prevented 8000 files from being read at start-up.
  * Mac and Linux scripting: fileReadable now returns 0 if the
    argument is a folder (as already on Windows).
* Thu Jan 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.04:
  * Typo in example script in manual.
* Tue Jan  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.02:
  * Saving sounds as MP3 files.
- Rebase praat-use_system_libs.patch to apply cleanly and also
  include lame as part of system libraries against which to link.
- New BuildRequires: pkgconfig(lame).
* Sat Dec  9 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.01:
  * Removed some visible percent signs before variable names from
    the scripting tutorial.
  * SoundEditor/TextGridEditor logging: when logging 'f0', Praat
    now correctly reports values in Hz (rather than logarithms) if
    Unit is set to “Hertz (logarithmic)”. This bug had existed
    since Praat version 4.3.16 (June 2005).
  * SoundEditor/TextGridEditor scripting compatibility: made old
    versions of “Pitch settings...” and “Advanced pitch
    settings...” available to scripts again, made the old
    denominations “autocorrelation” and “cross-correlation” (as
    pitch analysis methods) available to scripts again, and made
    obsolete versions of pitch analysis settings (such as “Pitch
    silence threshold”) available again, now under the
    COMPATIBILITY section of the output of “Editor info”.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4:
  * New pitch analysis methods: Sound: To Pitch (filtered ac)...
    and Sound: To Pitch (filtered cc)....
  * Sound: To Pitch (filtered ac)... has become the preferred
    method for measuring vocal-fold vibration and intonation
- Add rpmlintrc file to disable warning about no-pie, whereas this
  is intended by upstream.
* Mon Oct 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.20:
  * SpeechSynthesizer and automatic alignment in TextGridEditor:
    worked around a bug introduced in 6.3.18 that caused incorrect
    rendering of phonemes consisting of four UTF-8 bytes (such as
    /ɔː/).
  * SpeechSynthesizer and automatic alignment in TextGridEditor:
    worked around a very old bug that deleted word-final /l/ in
    Dutch and English.
* Tue Oct 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.18:
  * SpeechSynthesizer: included the new version of eSpeak
    (development 1.52), which has 133 languages.
  * Add to menu...: you can now add separators, headers and
    indented submenus to menus in editor windows.
  * Scripting: new functions index_caseInsensitive,
    rindex_caseInsensitive, startsWith_caseInsensitive,
    endsWith_caseInsensitive fileNames_caseInsensitive$#,
    folderNames_caseInsensitive$#.
* Tue Sep 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.17:
  * SoundEditor: three Paste options, namely Paste before
    selection (Shift-Command-V), Paste over selection
    (Option-Command-V), and the already existing Paste after
    selection (now Command-V).
  * All editor windows: extended the old single-level Undo and
    Redo to a ten-level Undo and Redo.
  * Scripting: the new runSystem$ and runSubprocess$ return the
    output of the system command or subprocess.
  * Scripting: runSystem, runSystem$, runSubprocess and
    runSubprocess$ report any error messages generated by the
    system command or subprocess.
  * PointEditor (pulses): settable Period floor, Period ceiling,
    Maximum period factor and Maximum amplitude factor, for jitter
    and shimmer measurements.
* Mon Sep  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.16:
  * Sound analysis areas: better visible contrast in intensity
    curve (green on lime).
  * Windows: repaired a bug introduced in 6.3.10 (as a result of
    the repair mentioned there) by which the Demo window would be
    insensitive to arrow keys.
  * SpeechSynthesizer: repaired a bug that caused Get phonemes
    from text... to return empty text.
  * Repaired a bug that caused Praat to crash when you supplied 0
    for the channel number in Sound: Get nearest zero crossing.
* Thu Aug  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.13:
  * Fixed a bug introduced in 6.3.12 by which a link to a file
    wasn’t found in external manual pages.
* Sat Jul 29 2023 Dirk Müller <dmueller@suse.com>
- update to 6.3.12:
  * Improvements in manual, including corrections on layout
    problems introduced in version 6.3.11.
* Fri Jul 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.11:
  * VowelEditor: repaired a bug by which the VowelEditor wouldn’t
    start up if an incorrect marks file had previously been
    specified.
  * OTMulti: vertical constraint names support newlines and
    disharmonies.
  * Text windows are one tab plus 84.5 characters wide.
  * Table: Get all values in column....
  * Undocumented alpha support for Praat notebooks.
  * Formulas: correlation (vec1#, vec2#), vertical$ (for
    formatting string arrays).
  * Scripting: readFile#, readFile##.
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.10:
  * Repaired a bug in the VowelEditor by which it would crash when
    starting up after fewer than 4 numbers were set in the “Extra
    formant–bandwidth pairs” field.
  * FormantPathEditor improvements.
  * Undocumented alpha support for Praat notebooks.
  * Scripting: vector literals can be indexed.
  * Better interactions between editor scripts and pause windows.
* Tue Mar 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.09:
  * SpeechSynthesizer can do eSpeak’s grapheme-to-phoneme
    conversion in 130 languages.
  * FormantPath can now have time stretches that are not aligned
    to frame boundaries.
  * Stabler handling of edge cases in editor scripting.
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.08:
  * Corrected a bug introduced in 6.3.04 by which word and
    sentence would not work in new-style script forms.
- Changes from version 6.3.01 to 6.3.07:
  * Corrected an old bug that caused Matrix: Draw as squares to
    crash on a 1×1 matrix.
  * NoulliGrid window: “NoulliGrid” menu.
  * Scripting: faster vectors in arguments to runScript().
  * Corrected a bug introduced in 6.3.04 by which optionmenu would
    not work in new-style script forms.
  * Scripting: min(), max(), imin() and imax() for vectors.
  * Corrected a bug introduced in 6.3.04 by which some old-style
    forms could not be read.
  * Repaired an old bug by which chooseReadString() could crash on
    Linux.
  * Playing multiple sounds with Play now concatenates them without
    breaks, and is interruptable by the Escape key.
  * Renamed the remaining occurrences of “Preferences” with
    “Settings” (old scripts will continue to work).
  * Create Polygon from values...
  * Sound: To Sound (derivative)...
  * Scripting: forms now look more like other commands.
  * Scripting: forms can contain infile, outfile, folder,
    realvector, positivevector, integervector and naturalvector
    fields.
  * Scripting: in forms and pause forms, you can now set the number
    of lines in text, infile, outfile, folder, and vector fields.
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to v6.3.03:
  * Sound files: read Kay® Nasometer™ files (as separate channels).
  * Script window: indent and exdent.
  * Scripting: conserve editor environment in runScript.
* Wed Nov 30 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.01:
  * Linux: corrected a bug introduced in 6.2.20 by which typing
    Tab would not start a Sound.
  * Sound window: corrected a bug introduced in 6.2.19 by which
    drawing selection hairs could not be switched off (or on) when
    painting a spectrogram to the Picture window.
- Add praat-allow-system-flags.patch: allow system specified
  compiler and linker flags to be incorporated into appropriate
  flags in the makefile; in particular this allows us to
  incorporate rpm optflags without using sed snippets.
- Rebase praat-use_system_libs.patch to apply cleanly.
- Clean up some trailing white-spaces in changelog entries.
- Drop praat-gcc11.patch: incorporated upstream.
* Fri Jun  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.48
  * TextGrid window: Shift-drag drags multiple boundaries again
    even if the Shift key is not released.
  * Scripting: publishing ("Extract") an object from an editor
    window returns its ID again.
  * Scripting: "Select..." in an editor window is now prevented
    from selecting outside the time domain.
  version 6.1.47:
  * The Escape key now means Cancel also in a non-pausing pause
    window.
  version 6.1.46:
  * Fixed a bug with line types in the Picture window.
  * TextGrid window: shift-click on a boundary again extends the
    selection.
  version 6.1.45:
  * Praat picture files can be drawn with Read from file again.
  version 6.1.44:
  * Scripting: queries in editor windows are scriptable again.
  version 6.1.43:
  * TextGrid window: characters in the IPA chart grow with the
    window.
  * TextGrid window: seeing the maroon shadow now always means
    that the boundary will be moved when the mouse is released
    (problem since 6.1.20 or so).
  version 6.1.42:
  * Settings windows: taller text fields for formulas and
    vectors.
- Add praat-gcc11.patch to fix build in Factory
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.41
  * TextGrid window: unselected boundaries can again be drawn to
    the cursor.
  * Windows: faster running cursor.
  * Multi-line formula fields.
  * Scripting: guard against too deep recursive calls to
    runScript (depth 20).
  * EEG: repaired a bug that could cause Praat to crash when
    computing an ERPTier.
  version 6.1.40:
  * Inspect window: corrected a bug that could cause Praat to
    crash when opening a string vector.
  * Sound window: made channel scrolling work again when there
    are more than 8 channels.
  * Sound window: made channel muting by clicking on the
    loudspeaker symbols work again.
- Refresh praat-use_system_libs.patch and
  praat-no-return-in-nonvoid.patch
* Thu Jan 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.38
  * Scripting: string vectors, empty$# (), readLinesFromFile$#
    (), fileNames$# (), folderNames$# (), splitByWhitespace$# ().
  * Sound files: open Ogg Vorbis files and Opus files.
  version 6.1.37:
  * TextGrid window: removed a bug that caused Praat to crash
    when option-clicking or command-clicking a boundary when
    another boundary was selected on a point tier.
  * PowerCepstrogram: more precise intergration, so that the
    cepstral peak prominence is now a continuous function of time.
  * TextGrid: Get points (preceded): removed a bug that caused
    Praat to crash under some edge conditions.
  * Scripting: tryToWriteFile () and tryToAppendFile () should
    not be available in manuals.
  version 6.1.36:
  * Scripting: tryToWriteFile (), tryToAppendFile (); formulas
    can have a size of 1 million.
  * Obscured scripts: error messages always disclosed.
  * IPA chart: sacrifice laminality symbol for breathiness
    symbol.
  version 6.1.35:
  * Scripting: sort#(), shuffle#(), to#(), from_to#(),
    from_to_by#(), from_to_count#(), between_by#(),
    between_count#().
  version 6.1.34:
  * SoundRecorder always a white background, instead of a
    different background on each platform.
  version 6.1.32:
  * Made Text width... work correctly from batch.
  * Reinstalled Tab shortcut in Sound window.
  version 6.1.31:
  * First GTK-3 version.
  version 6.1.28:
  * Pause forms: text fields can be multi-line.
  * Removed a bug that caused Praat to crash when editing a
    PitchTier.
  * Script window: got rid of too many history entries after
    dragging in the Picture window.
  version 6.1.27:
  * Demo window: make sure that the contents of the window
    become visible more often without calling demoShow() or
    demoWaitForInput().
- Refreshed praat-use_system_libs.patch
- Switched build to gtk3
* Wed Oct  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Use icns-utils instead of heavy duty ImageMagick and install
  multiple-size icons in the proper folders
* Wed Oct  7 2020 Juan Erbes <jerbes@gmail.com>
- Update to version 6.1.26
  * Removed a bug that caused Praat to crash when clicking Change
    in the Inspect window.
  version 6.1.25
  * Added FormantPath and FormantPathEditor.
  * Removed a bug that caused Praat to crash when double-clicking
    in the Sound window.
  * Removed a bug that caused Praat to crash when raising the About
    window twice.
  * Removed a bug that caused Praat to crash when zooming in to a
    region in the Sound window without samples, when a pitch curve
    was visible.
  * Removed a bug that caused Praat to crash when pasting
    in a region in the Sound window without samples.
  version 6.1.24
  * Got rid of flashing during a running cursor or when making a
    selection in the Sound window or the Picture window.
  version 6.1.23
  * Corrected a bug that caused the buttons at the top of a manual
    window to be overwritten with text when scrolling.
* Fri Sep 25 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.22
  * Corrected a bug introduced in 6.1.17alpha that could cause
    incorrect line spacing in the Picture window, such as in
    TableOfReal: Draw as numbers.
  version 6.1.21
  * First fully functional version for BigSur.
  * Removed a decades-old bug by which an extremum allegedly
    computed by cubic interpolation would actually have been
    computed by sinc700.
  version 6.1.16
  * Record fixed time...: more reliable choice of input device.
  version 6.1.15
  * Repaired a bug introduced in 6.0.44 that could cause an
    incorrect (namely, totally constant) ClassificationTable.
  version 6.1.14
  * Repaired a bug in drawing ranges introduced in 6.1.06.
  version 6.1.13a
  * Repaired discriminant analysis on i386 processors.
  * Scripting: enabled predictability by setting random seeds.
  * Automated batch testing on x86_64, i386 and ARMv7 processors.
  version 6.1.12
  * All non-GUI tests can be automated from batch.
  * Repaired a bug introduced in 6.0 whereby a
    KlattGrid-generated Sound would always be peak-scaled.
  version 6.1.11
  * Better messages
  * Overhauled VowelEditor.
  * Repaired crashes after creating a Formant from a Spectrum or
    an Excitation.
- Refreshed praat-use_system_libs.patch and
  praat-no-return-in-nonvoid.patch
* Tue Mar 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.10
  * Faster formant computation.
  * More LPC queries.
  version 6.1.09
  * Accept some more kinds of broken WAV files.
  * Improved box plot drawing.
  * More Network commands.
  version 6.1.08
  * Repaired a bug with automatic alignment for TextGrids
    (introduced in 6.1.07).
- Refreshed praat-use_system_libs.patch
* Fri Nov 29 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.07
  * Raspberry Pi edition.
  version 6.1.06:
  * Chromebook edition.
  * Scripting: colour fields now take name, grey value or RGB
    vector.
  version 6.1.05:
  * Repaired a bug introduced in 6.0.44 that could cause rubbish
    LPC smoothing.
  * Repaired a rare crash when dragging a selection on the Mac.
  version 6.1.04:
  * Electroglottography.
  * Sound and other windows: Widen or shrink selection....
  * KlattGrid: Create from vowel....
  * Fix rectangle playing bug when selection viewer is on.
  * Selection viewer separately visible for Sound window and
    TextGrid window.
  * Scripting: allow comments after parameter list.
  * Scripting: fix CR/LF pasting from Microsoft Word.
  version 6.1.03:
  * Sound window: Widen or shrink selection....
  version 6.1.02:
  * Repaired Sound: Concatenate with overlap....
  * Mac: Info and script windows: prevent line breaks caused by
    tab stops.
  version 6.1.01:
  * Repaired TextGrid: Replace interval texts....
- Refreshed praat-use_system_libs.patch
* Sat Jul 13 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1
  * major update
  version 6.0.56:
  * SpellingChecker: Unicode support.
  version 6.0.55:
  * Unicode normalization in file names.
  version 6.0.54:
  * Removed a bug introduced in 6.0.51 that could cause
    incorrect axes in Demo window.
  version 6.0.53:
  * Much faster playing of short parts of long sounds that need
    resampling.
  * Better handling of broken CSV files.
  * 64-bit floating-point WAV files.
  version 6.0.52:
  * Removed a bug introduced in 6.0.51 that could cause turning
    a Discriminant into a Configuration to crash.
  * Removed a bug introduced in contour grey drawing in August
    2017.
  version 6.0.51:
  * Script window: Use Selection for Find.
  * Corrected a bug that could cause Praat to crash after
    removing an element from a Strings or a row from a
    TableOfReal.
  version 6.0.50:
  * Manual updates, speed, more tests.
  * Scripting: rowSums#, columnSums#; randomGauss## finally with
    four arguments.
* Sat Mar  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.49
  * Removed a bug introduced in 6.0.41 whereby a script could
    misreport an undefined table value.
  * Removed a bug introduced in 6.0.44 whereby an MFCC's maximum
    frequency could be ignored.
  * Pitch: Tabulate candidates.
  * SoundSet.
* Sun Feb 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.48
  * Removed a bug introduced in 6.0.44 whereby Praat could crash
    when drawing a function without any points.
* Sat Feb  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.47
  * Removed a bug introduced in 6.0.44 whereby a cepstral peak
    prominence would be computed incorrectly.
* Thu Jan  3 2019 aloisio@gmx.com
- Update to version 6.0.46
  * Removed a crashing bug in the LongSound window introduced in
    6.0.44.
  * Removed a bug causing incorrect conversion from Formant to
    LPC introduced in 6.0.44.
  * More space for actions in buttons window.
* Tue Jan  1 2019 aloisio@gmx.com
- Update to version 6.0.45
  * Removed a crashing bug in EditDistanceTable introduced in
    6.0.44.
  * Removed a crashing bug in KlattGrid drawing introduced in
    6.0.44.
  * Removed a bug introduced in 6.0.44 whereby old HMM files
    were read incorrectly.
  version 6.0.44
  * Bug fixes and speed.
- Refreshed praat-no-return-in-nonvoid.patch
* Sat Sep  8 2018 aloisio@gmx.com
- Update to version 6.0.43
  * Removed a very old bug that could create invalid TextGrids
    during forced alignment.
- Refreshed praat-no-return-in-nonvoid.patch
* Thu Aug 16 2018 aloisio@gmx.com
- Update to version 6.0.42
  * Repaired a bug introduced in 6.0.41 that caused a crash in
    pause windows.
- Refreshed praat-use_system_libs.patch and
  praat-no-return-in-nonvoid.patch
* Tue Aug  7 2018 aloisio@gmx.com
- Update to version 6.0.41
  * Interoperability: the Windows edition can now communicate
    with other software in UTF-8.
- Refreshed praat-no-return-in-nonvoid.patch
* Sat May 12 2018 aloisio@gmx.com
- Update to version 6.0.40
  * Scripting: selected# ().
  * Table window: cell selection.
  * Unicode-savvy regular expressions.
- Add praat-no-return-in-nonvoid.patch
* Fri Mar 30 2018 aloisio@gmx.com
- Update to version 6.0.38
  * Concordance: ##TextGrid: Tabulate occurrences...#.
  * Some Independent Component Analysis on EEG.
  * Removed many small bugs
* Sun Feb  4 2018 aloisio@gmx.com
- Update to version 6.0.37
  * Graphics: fixed crashing bug with \un trigraph.
* Sat Nov 11 2017 aloisio@gmx.com
- Update to version 6.0.36
  * Many more languages for SpeechSynthesizer and automatic
    alignment (new eSpeak).
- Refreshed praat-use_system_libs.patch
* Tue Oct 17 2017 aloisio@gmx.com
- Update to version 6.0.35
  * Fixed a bug introduced in 6.0.23 by which Remove right
    boundary would sometimes incorrectly refuse.
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 6.0.34
  * Scripting: arrays in menu commands in scripts.
  * Inspect: made a button visible that had disappeared in 6.0.33.
* Tue Sep 26 2017 aloisio@gmx.com
- Update to version 6.0.33
  * Pitch: Subtract linear fit...: correct a bug that prevented
    computation in the ERB domain.
  * Scripting: made object[xx].xmin work again.
  * Removed a bug in Polynomial: Evaluate... introduced in 6.0.32.
- Dropped praat-fix_return_nonvoid.patch (merged upstream)
* Sun Sep 17 2017 aloisio@gmx.com
- Update to version 6.0.32
  * Table: allow spaces in column names.
  * Settings windows no longer replace your visible expressions
    with their resulting values.
  * Scripting: formulas using the tilde.
  * Optimality Theory learning: corrected a bug introduced in
    6.0.30 that could cause the editor to crash on the Mac.
  * EEG: corrected a bug that could cause an infinite loop when
    doing principal component analysis.
  * Scripting: faster interpreter.
- Refreshed praat-use_system_libs.patch
- Added praat-fix_return_nonvoid.patch
* Tue Aug 22 2017 aloisio@gmx.com
- Update to 6.0.31
  * Scripting: more vectors and matrices.
  * Numerics: faster and more precise sums, means, standard
    deviations.
- Refreshed praat-use_system_libs.patch
- Dropped praat-6.0.30-no-return-in-nonvoid.patch
* Sat Jul 29 2017 aloisio@gmx.com
- Added praat-use_system_libs.patch to use system libs when
  possible
* Sun Jul 23 2017 aloisio@gmx.com
- Update to version 6.0.30
  * Removed a bug that caused an incorrect title for a PitchTier
    or PointProcess window.
  * Removed a bug that caused Praat to crash when doing a linear
    regression on a Table with no rows.
  * Scripting: object[], vectors.
  * Graphics: better text drawing details.
  * Linux: possibility to compile Praat without a GUI but with
    graphics file output.
- Added praat-6.0.30-no-return-in-nonvoid.patch
* Sat Jun 24 2017 bwiedemann@suse.com
- Use convert -strip to not add timestamps to png files
* Wed May 24 2017 aloisio@gmx.com
- Update to 6.0.29
  * Sound window: channel muting.
  * Linux: support for Chinese, Japanese, Korean, Indic, Arabic
    and Hebrew characters in TextGrids and elsewhere.
- Dropped praat-rpmlint_warnings.patch (merged upstream)
* Mon May  8 2017 aloisio@gmx.com
- Improved description
* Thu May  4 2017 aloisio@gmx.com
- Added %%optflags
- Added praat-rpmlint_warnings.patch
* Tue May  2 2017 aloisio@gmx.com
- Corrected license
* Thu Mar 23 2017 aloisio@gmx.com
- Update to version 6.0.28
  * Scripting: demoPeekInput() for animations in combination
    with demoShow() and sleep().
* Sat Mar 18 2017 aloisio@gmx.com
- Update to version 6.0.27
  * Fixed a bug by which Remove right boundary would choose
    the wrong tier.
  * TextGrid window: click to insert a phonetic symbol from
    an IPA chart.
* Thu Mar  2 2017 aloisio@gmx.com
- Update to version 6.0.26
  * PraatBarren: better error message when an attempt is made
    to run PraatBarren interactively.
* Sun Feb 12 2017 aloisio@gmx.com
- Update to version 6.0.25
* Mon Dec 12 2016 aloisio@gmx.com
- Update to version 6.0.23
  * Linux: fixed a bug that caused Praat to crash when
    playing a sound of more than 7 channels.
  * Change Gender: fixed a bug introduced in 6.0.22 by
    which the pitch range factor could not be 0.
  * Improvements in the manual and in texts.
* Wed Nov 16 2016 aloisio@gmx.com
- Update to version 6.0.22
  * Scripting: correct error messages for expressions
    like 5 + "hello"
  * Command line: the --open option works correctly in
    the GUI if you open multiple files.
* Mon Sep 26 2016 aloisio@gmx.com
- Update to version 6.0.21
  * ExperimentMFC: you can now specify font sizes and response
    keys for goodness judgments.
  * Table: when drawing ellipses, a font size of 0 can now be
    used to prevent drawing the labels.
  * Mac: dragging selections repaired for System 10.11.6 (but
    we advise to upgrade to 10.12).
  * Mac: re-enabled Return key for confirming some dialog
    boxes.
* Sun Sep  4 2016 aloisio@gmx.com
- Update to version 6.0.20
  * Can open UTF-8 text files with Byte Order Mark.
  * Scripting improvement: function names can now be used
    as names of indexed variables.
* Tue Jul 19 2016 toddrme2178@gmail.com
- Update to version 6.0.19
  * Mac: dragging selections repaired for System 10.11.5.
* Tue May 24 2016 aloisio@gmx.com
- Update to version 6.0.18
  * Windows: better dotted lines.
  * TextGrid window: again better automatic alignment.
* Thu Apr 21 2016 aloisio@gmx.com
- Update to version 6.0.17
  * TextGrid window: better automatic alignment.
- Removed praat.png and praat.desktop as Source1 and Source2
  and produced them internally
* Tue Apr 19 2016 aloisio@gmx.com
- Initial version 6.0.16
